# Starhopper

Starhopper is a tool for extracting data from Bethesda's Starfield game. It:

- Provides a low level Python library for reading the game's data files.
- Provides a Qt-based GUI for exploring the game's data files.

This tool is currently in _early_ development. The game quite literally just
got released.
